@@ -1,7 +1,7 @@
 from control.matlab import *
 import pandas as pd
 import numpy as np
-from engine.devices.auxiliaries import *
+from SSTool.engine.devices.auxiliaries import *
 
 
 def create(df_SG, w):
