@@ -10,7 +10,7 @@ import sys
 # from control.matlab import *
 # import matplotlib.pyplot as plt
 # import numpy as np
-from engine.devices import auxiliaries
+from SSTool.engine.devices import auxiliaries
 
 
 def bode_YZ(ss_class, f_ini=0, f_fin=3, name_in=[], name_out=[], n_p=1000, logx = False, dBy = False, invert = False):
