@@ -8,10 +8,6 @@ pd.set_option('display.width', 1000)
 from control.matlab import *
 
 
-# from Functions_v1 import *
-# from core.functions_to_organize import *
-# from core import functions_to_organize
-# from engine import build
 # from SSTool.engine import build  # global, from the pip install
 from engine import build, stability
 import os.path
@@ -31,8 +27,8 @@ syst = build.create_syst(fullpath)
 # stability.eigen(syst.VSCs[0], plot=True, prnt=True)
 
 # nyquist
-# side1 = syst.VSCs[0]
-# side2 = stability.merge_all_minus1(fullpath, syst, 'VSC', 0)
-# stability.nyquist_YZ(ss_class_act=side1, ss_class_psv=side2, f_ini=1.0, f_fin=3.0, name_in=['vq_1', 'vd_1'], name_out=['iqxv_1', 'idxv_1'], n_p=10000, n_arrows=5, invert=False)
+side1 = syst.VSCs[0]
+side2 = stability.merge_all_minus1(fullpath, syst, 'VSC', 0)
+stability.nyquist_YZ(ss_class_act=side1, ss_class_psv=side2, f_ini=1.0, f_fin=3.0, name_in=['vq_1', 'vd_1'], name_out=['iqxv_1', 'idxv_1'], n_p=10000, n_arrows=5, invert=False)
 
 
